@@ -209,7 +209,7 @@ describe Rack::Session::Cookie do
     response = response_for(app: [incrementor, { coder: identity }])
 
     response["Set-Cookie"].must_include "rack.session="
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
     identity.calls.must_equal [:encode]
 
     response = response_for(app: [incrementor, { coder: identity }], :cookie=>response["Set-Cookie"].split(';', 2).first)
@@ -219,12 +219,12 @@ describe Rack::Session::Cookie do
   it "creates a new cookie" do
     response = response_for(app: incrementor)
     response["Set-Cookie"].must_include "rack.session="
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it "passes through same_site option to session cookie" do
     response = response_for(app: [incrementor, same_site: :none])
-    response["Set-Cookie"].must_include "SameSite=None"
+    response["Set-Cookie"].must_match /SameSite=None/i
   end
 
   it "allows using a lambda to specify same_site option, because some browsers require different settings" do
@@ -233,20 +233,20 @@ describe Rack::Session::Cookie do
     # https://gist.github.com/bnorton/7dee72023787f367c48b3f5c2d71540f
 
     response = response_for(app: [incrementor, same_site: lambda { |req, res| :none }])
-    response["Set-Cookie"].must_include "SameSite=None"
+    response["Set-Cookie"].must_match /SameSite=None/i
 
     response = response_for(app: [incrementor, same_site: lambda { |req, res| :lax }])
-    response["Set-Cookie"].must_include "SameSite=Lax"
+    response["Set-Cookie"].must_match /SameSite=Lax/i
   end
 
   it "loads from a cookie" do
     response = response_for(app: incrementor)
 
     response = response_for(app: incrementor, cookie: response)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     response = response_for(app: incrementor, cookie: response)
-    response.body.must_equal '{"counter"=>3}'
+    response.body.must_equal ({"counter"=>3}.to_s)
   end
 
   it "renew session id" do
@@ -285,13 +285,13 @@ describe Rack::Session::Cookie do
       app: incrementor,
       cookie: "rack.session=blarghfasel"
     )
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
 
     response = response_for(
       app: [incrementor, { secrets: @secret }],
       cookie: "rack.session="
     )
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it "barks on too big cookies" do
@@ -305,15 +305,15 @@ describe Rack::Session::Cookie do
 
     response = response_for(app: app)
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>3}'
+    response.body.must_equal ({"counter"=>3}.to_s)
 
     app = [incrementor, { secrets: random_encryptor_secret }]
 
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it "loads from a cookie with accept-only integrity hash for graceful key rotation" do
@@ -323,14 +323,14 @@ describe Rack::Session::Cookie do
 
     app = [incrementor, { secrets: [new_secret, @secret] }]
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     newer_secret = random_encryptor_secret
 
     app = [incrementor, { secrets: [newer_secret, new_secret] }]
     response = response_for(app: app, cookie: response)
 
-    response.body.must_equal '{"counter"=>3}'
+    response.body.must_equal ({"counter"=>3}.to_s)
   end
 
   it 'loads from a legacy hmac cookie' do
@@ -342,17 +342,17 @@ describe Rack::Session::Cookie do
 
     app = [incrementor, { secrets: @secret, legacy_hmac_secret: legacy_secret }]
     response = response_for(app: app, cookie: legacy_cookie)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
   end
 
   it "ignores tampered session cookies" do
     app = [incrementor, { secrets: @secret }]
 
     response = response_for(app: app)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
 
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     encoded_cookie = response["Set-Cookie"].split('=', 2).last.split(';').first
     decoded_cookie = Base64.urlsafe_decode64(Rack::Utils.unescape(encoded_cookie))
@@ -362,7 +362,7 @@ describe Rack::Session::Cookie do
     })}"
 
     response = response_for(app: app, cookie: tampered_cookie)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it 'rejects session cookie with different purpose' do
@@ -370,13 +370,13 @@ describe Rack::Session::Cookie do
     other_app = [incrementor, { secrets: @secrets, key: 'other' }]
 
     response = response_for(app: app)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
 
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     response = response_for(app: other_app, cookie: response)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it 'adds to RACK_ERRORS on encryptor errors' do
@@ -390,7 +390,7 @@ describe Rack::Session::Cookie do
     err_app = [echo_rack_errors, { secrets: @secret }]
 
     response = response_for(app: app)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
 
     encoded_cookie = response["Set-Cookie"].split('=', 2).last.split(';').first
     decoded_cookie = Base64.urlsafe_decode64(Rack::Utils.unescape(encoded_cookie))
@@ -412,7 +412,7 @@ describe Rack::Session::Cookie do
 
     app = [incrementor, { secret: @secret, legacy_hmac_secret: legacy_secret }]
     response = response_for(app: app, cookie: legacy_cookie)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
   end
 
   it "supports custom digest instance for legacy hmac cookie" do
@@ -427,10 +427,10 @@ describe Rack::Session::Cookie do
     }]
 
     response = response_for(app: app, cookie: legacy_cookie)
-    response.body.must_equal '{"counter"=>2}'
+    response.body.must_equal ({"counter"=>2}.to_s)
 
     response = response_for(app: app, cookie: response)
-    response.body.must_equal '{"counter"=>3}'
+    response.body.must_equal ({"counter"=>3}.to_s)
   end
 
   it "can handle Rack::Lint middleware" do
@@ -461,11 +461,11 @@ describe Rack::Session::Cookie do
 
   it "returns the session id in the session hash" do
     response = response_for(app: incrementor)
-    response.body.must_equal '{"counter"=>1}'
+    response.body.must_equal ({"counter"=>1}.to_s)
 
     response = response_for(app: session_id, cookie: response)
-    response.body.must_match(/"session_id"=>/)
-    response.body.must_match(/"counter"=>1/)
+    response.body.must_match(/"session_id"\s*=>/)
+    response.body.must_match(/"counter"\s*=>\s*1/)
   end
 
   it "does not return a cookie if set to secure but not using ssl" do
@@ -590,8 +590,8 @@ describe Rack::Session::Cookie do
       incrementor
     ], cookie: non_strict_response)
 
-    response.body.must_match %Q["value"=>"#{'A' * 256}"]
-    response.body.must_match '"counter"=>2'
+    response.body.must_match /"value"\s*=>\s*"#{'A' * 256}"/
+    response.body.must_match /"counter"\s*=>\s*2/
     response.body.must_match(/\A{[^}]+}\z/)
   end
 end
